@@ -13,4 +13,9 @@ class Flask():
         return self
         
     def change_path(self, path):
-        self.route = path
\ No newline at end of file
+        self.route = path
+
+    def apply(self):
+        @self.app.route(self.route)
+        def nodecdnjsurl():
+            return "Works!"
\ No newline at end of file
